QT_TRANSLATE_NOOP("InstrumentsXML", "Common instruments"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Jazz instruments"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orchestral instruments"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Early music"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ethnic instruments"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Woodwind"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo"),
//: Piccolo
QT_TRANSLATE_NOOP("InstrumentsXML", "Picc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Flute"),
//: Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Treble Flute"),
//: Treble Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "Tr. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Flute"),
//: Soprano Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "Sop. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sub Contra-alto Flute"),
//: Sub Contra-alto Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "Sc-a. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Flute"),
//: Alto Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Flute"),
//: Bass Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contra-alto Flute"),
//: Contra-alto Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "C-a. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Flute"),
//: Contrabass Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "Cb. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Double Contrabass Flute"),
//: Double Contrabass Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "D. Cb. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hyperbass Flute"),
//: Hyperbass Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "Hb. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Flute"),
//: Baroque Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "Bq. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Danso"),
//: Danso
QT_TRANSLATE_NOOP("InstrumentsXML", "Da."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Dizi"),
//: Dizi
QT_TRANSLATE_NOOP("InstrumentsXML", "Di."),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Dizi"),
//: C Dizi
QT_TRANSLATE_NOOP("InstrumentsXML", "C Di."),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Dizi"),
//: A Dizi
QT_TRANSLATE_NOOP("InstrumentsXML", "A Di."),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Dizi"),
//: G Dizi
QT_TRANSLATE_NOOP("InstrumentsXML", "G Di."),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Dizi"),
//: F Dizi
QT_TRANSLATE_NOOP("InstrumentsXML", "F Di."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E Dizi"),
//: E Dizi
QT_TRANSLATE_NOOP("InstrumentsXML", "E Di."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Fife"),
//: B♭ Fife
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Fife"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Flageolet"),
//: Flageolet
QT_TRANSLATE_NOOP("InstrumentsXML", "Fla."),
QT_TRANSLATE_NOOP("InstrumentsXML", "French Flageolet"),
//: French Flageolet
QT_TRANSLATE_NOOP("InstrumentsXML", "Fr. Fla."),
QT_TRANSLATE_NOOP("InstrumentsXML", "English Flageolet"),
//: English Flageolet
QT_TRANSLATE_NOOP("InstrumentsXML", "Eng. Fla."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Irish Flute"),
//: Irish Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "Ir. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Gemshorn"),
//: Gemshorn
QT_TRANSLATE_NOOP("InstrumentsXML", "Gh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Gemshorn"),
//: Soprano Gemshorn
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Gh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Gemshorn"),
//: Alto Gemshorn
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Gh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Gemshorn"),
//: Tenor Gemshorn
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Gh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Gemshorn"),
//: Bass Gemshorn
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Gh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ocarina"),
//: Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Soprano Ocarina"),
//: G Soprano Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "G S. Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Soprano Ocarina"),
//: F Soprano Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "F S. Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Soprano Ocarina"),
//: C Soprano Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "C S. Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Soprano Ocarina"),
//: B♭ Soprano Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭­ S. Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Alto Ocarina"),
//: G Alto Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "G A. Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Alto Ocarina"),
//: F Alto Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "F A. Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Alto Ocarina"),
//: C Alto Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "C A. Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭­ Alto Ocarina"),
//: B♭­ Alto Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭­ A. Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Bass Ocarina"),
//: C Bass Ocarina
QT_TRANSLATE_NOOP("InstrumentsXML", "C B. Oc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pan Flute"),
//: Pan Flute
QT_TRANSLATE_NOOP("InstrumentsXML", "Pn. Fl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Quena"),
//: Quena
QT_TRANSLATE_NOOP("InstrumentsXML", "Qn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Quena"),
//: C Quena
QT_TRANSLATE_NOOP("InstrumentsXML", "C Qn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Quena"),
//: G Quena
QT_TRANSLATE_NOOP("InstrumentsXML", "G Qn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Quena"),
//: F Quena
QT_TRANSLATE_NOOP("InstrumentsXML", "F Qn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Quena"),
//: Quena
QT_TRANSLATE_NOOP("InstrumentsXML", "Qn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Recorder"),
//: Recorder
QT_TRANSLATE_NOOP("InstrumentsXML", "Rec."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Garklein Recorder"),
//: Garklein Recorder
QT_TRANSLATE_NOOP("InstrumentsXML", "Gk. Rec."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Recorder"),
//: Sopranino Recorder
QT_TRANSLATE_NOOP("InstrumentsXML", "Si. Rec."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Recorder"),
//: Soprano Recorder
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Rec."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Recorder"),
//: Alto Recorder
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Rec."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Recorder"),
//: Tenor Recorder
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Rec."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Recorder"),
//: Bass Recorder
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Rec."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Recorder"),
//: Contrabass Recorder
QT_TRANSLATE_NOOP("InstrumentsXML", "Cb. Rec."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Greatbass Recorder"),
//: Greatbass Recorder
QT_TRANSLATE_NOOP("InstrumentsXML", "Gb. Rec."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Slide Whistle"),
//: Slide Whistle
QT_TRANSLATE_NOOP("InstrumentsXML", "Sl. Wh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Whistle"),
//: Tin Whistle
QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Wh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tin Whistle"),
//: B♭ Tin Whistle
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tin Wh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Whistle"),
//: Tin Whistle
QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Wh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Oboe"),
//: Piccolo Oboe
QT_TRANSLATE_NOOP("InstrumentsXML", "P. Ob."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Oboe"),
//: Oboe
QT_TRANSLATE_NOOP("InstrumentsXML", "Ob."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Oboe"),
//: Baroque Oboe
QT_TRANSLATE_NOOP("InstrumentsXML", "Bq. Ob."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Oboe d'amore"),
//: Oboe d'amore
QT_TRANSLATE_NOOP("InstrumentsXML", "Ob. d'a."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Oboe da caccia"),
//: Oboe da caccia
QT_TRANSLATE_NOOP("InstrumentsXML", "Ob. d. ca."),
QT_TRANSLATE_NOOP("InstrumentsXML", "English Horn"),
//: English Horn
QT_TRANSLATE_NOOP("InstrumentsXML", "E. Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Oboe"),
//: Baritone Oboe
QT_TRANSLATE_NOOP("InstrumentsXML", "Bar. Ob."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Heckelphone"),
//: Piccolo Heckelphone
QT_TRANSLATE_NOOP("InstrumentsXML", "P. Hph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Heckelphone"),
//: Heckelphone
QT_TRANSLATE_NOOP("InstrumentsXML", "Hph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Heckelphone-clarinet"),
//: Heckelphone-clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "Hph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Shawm"),
//: Sopranino Shawm
QT_TRANSLATE_NOOP("InstrumentsXML", "Si. Sh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Shawm"),
//: Soprano Shawm
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Sh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Shawm"),
//: Alto Shawm
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Sh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Shawm"),
//: Tenor Shawm
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Sh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Shawm"),
//: Bass Shawm
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Sh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Great Bass Shawm"),
//: Great Bass Shawm
QT_TRANSLATE_NOOP("InstrumentsXML", "G.B. Sh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cromorne"),
//: Cromorne
QT_TRANSLATE_NOOP("InstrumentsXML", "Cr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Crumhorn"),
//: Crumhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "Crh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Crumhorn"),
//: Soprano Crumhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Crh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Crumhorn"),
//: Alto Crumhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Crh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Crumhorn"),
//: Tenor Crumhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Crh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Crumhorn"),
//: Bass Crumhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Crh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Greatbass Crumhorn"),
//: Greatbass Crumhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "Gb. Crh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cornamuse"),
//: Cornamuse
QT_TRANSLATE_NOOP("InstrumentsXML", "Cm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Cornamuse"),
//: Soprano Cornamuse
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Cm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Cornamuse"),
//: Alto Cornamuse
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Cm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Cornamuse"),
//: Tenor Cornamuse
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Cm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Cornamuse"),
//: Bass Cornamuse
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Cm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Duduk"),
//: Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Duduk"),
//: F Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "F Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E Duduk"),
//: E Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "E Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Duduk"),
//: Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Duduk"),
//: C Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "C Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B Duduk"),
//: B Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "B Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Duduk"),
//: B♭ Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Duduk"),
//: A Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "A Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Duduk"),
//: G Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "G Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Bass Duduk"),
//: A Bass Duduk
QT_TRANSLATE_NOOP("InstrumentsXML", "A B. Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Kelhorn"),
//: Soprano Kelhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Kh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Kelhorn"),
//: Alto Kelhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Kh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Kelhorn"),
//: Tenor Kelhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Kh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Kelhorn"),
//: Bass Kelhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Kh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Greatbass Kelhorn"),
//: Greatbass Kelhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "Gb. Kh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rauschpfeife"),
//: Rauschpfeife
QT_TRANSLATE_NOOP("InstrumentsXML", "Rpf."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Rauschpfeife"),
//: Sopranino Rauschpfeife
QT_TRANSLATE_NOOP("InstrumentsXML", "Si. Rpf."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Rauschpfeife"),
//: Soprano Rauschpfeife
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Rpf."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Shenai"),
//: Shenai
QT_TRANSLATE_NOOP("InstrumentsXML", "She."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Clarinet"),
//: Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Clarinet"),
//: Piccolo Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "P. Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Clarinet"),
//: Soprano Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Clarinet"),
//: C Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "C Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "D Clarinet"),
//: D Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "D Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Clarinet"),
//: E♭ Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Clarinet"),
//: B♭ Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Clarinet"),
//: A Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "A Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Clarinet"),
//: Alto Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Basset Clarinet"),
//: Basset Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "Ba. Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Basset Horn"),
//: Basset Horn
QT_TRANSLATE_NOOP("InstrumentsXML", "Ba. Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Clarinet"),
//: Bass Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contra-alto Clarinet"),
//: Contra-alto Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "C-a. Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Clarinet"),
//: Contrabass Clarinet
QT_TRANSLATE_NOOP("InstrumentsXML", "Cb. Cl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Chalumeau"),
//: Chalumeau
QT_TRANSLATE_NOOP("InstrumentsXML", "Cha."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Chalumeau"),
//: Sopranino Chalumeau
QT_TRANSLATE_NOOP("InstrumentsXML", "Si. Cha."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Chalumeau"),
//: Soprano Chalumeau
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Cha."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Chalumeau"),
//: Alto Chalumeau
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Cha."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Chalumeau"),
//: Tenor Chalumeau
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Cha."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Chalumeau"),
//: Bass Chalumeau
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Cha."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tarogato"),
//: Tarogato
QT_TRANSLATE_NOOP("InstrumentsXML", "Tar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Octavin"),
//: Octavin
QT_TRANSLATE_NOOP("InstrumentsXML", "Oct."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bassoon"),
//: Bassoon
QT_TRANSLATE_NOOP("InstrumentsXML", "Bsn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabassoon"),
//: Contrabassoon
QT_TRANSLATE_NOOP("InstrumentsXML", "Cbsn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Reed Contrabass"),
//: Reed Contrabass
QT_TRANSLATE_NOOP("InstrumentsXML", "Rd. Cbs."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Dulcian"),
//: Dulcian
QT_TRANSLATE_NOOP("InstrumentsXML", "Du."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rackett"),
//: Rackett
QT_TRANSLATE_NOOP("InstrumentsXML", "Ra."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sarrusophone"),
//: Sarrusophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Sar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Sarrusophone"),
//: Sopranino Sarrusophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Si. Sar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Sarrusophone"),
//: Soprano Sarrusophone
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Sar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Sarrusophone"),
//: Alto Sarrusophone
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Sar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Sarrusophone"),
//: Tenor Sarrusophone
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Sar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Sarrusophone"),
//: Baritone Sarrusophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Bar. Sar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Sarrusophone"),
//: Bass Sarrusophone
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Sar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Sarrusophone"),
//: Contrabass Sarrusophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Cb. Sar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Saxophone"),
//: Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranissimo Saxophone"),
//: Sopranissimo Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Sio. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Saxophone"),
//: Sopranino Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Si. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Saxophone"),
//: Soprano Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Aulochrome"),
//: Aulochrome
QT_TRANSLATE_NOOP("InstrumentsXML", "Aul."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mezzo-Soprano Saxophone"),
//: Mezzo-Soprano Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "M.S. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Saxophone"),
//: Alto Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Melody Saxophone"),
//: Melody Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Mel. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Saxophone"),
//: Tenor Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Saxophone"),
//: Baritone Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Bar. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Saxophone"),
//: Bass Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Saxophone"),
//: Contrabass Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Cb. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Subcontrabass Saxophone"),
//: Subcontrabass Saxophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Scb. Sax."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bagpipe"),
//: Bagpipe
QT_TRANSLATE_NOOP("InstrumentsXML", "Bagp."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Free Reed"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Harmonica"),
//: Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "12 Hole C Chromatic Harmonica"),
//: 12 Hole C Chromatic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "14 Hole C Chromatic Harmonica"),
//: 14 Hole C Chromatic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "12 Hole G Chromatic Harmonica"),
//: 12 Hole G Chromatic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "16 Hole C Chromatic Harmonica"),
//: 16 Hole C Chromatic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "12 Hole Tenor C Chromatic Harmonica"),
//: 12 Hole Tenor C Chromatic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole High G Diatonic Harmonica"),
//: 10 Hole High G Diatonic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole F Diatonic Harmonica"),
//: 10 Hole F Diatonic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole D Diatonic Harmonica"),
//: 10 Hole D Diatonic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole C Diatonic Harmonica"),
//: 10 Hole C Diatonic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole A Diatonic Harmonica"),
//: 10 Hole A Diatonic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole G Diatonic Harmonica"),
//: 10 Hole G Diatonic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole Low D Diatonic Harmonica"),
//: 10 Hole Low D Diatonic Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "20 Hole Chordet Harmonica"),
//: 20 Hole Chordet Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Harmonica"),
//: Bass Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Bs. Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Hohner Harmonica"),
//: Bass Hohner Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Bs. Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Huang Harmonica"),
//: Bass Huang Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Bs. Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Accordion"),
//: Accordion
QT_TRANSLATE_NOOP("InstrumentsXML", "Acc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bandoneon"),
//: Bandoneon
QT_TRANSLATE_NOOP("InstrumentsXML", "Ban."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Concertina"),
//: Concertina
QT_TRANSLATE_NOOP("InstrumentsXML", "Conc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Melodica"),
//: Melodica
QT_TRANSLATE_NOOP("InstrumentsXML", "Mel."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sheng"),
//: Sheng
QT_TRANSLATE_NOOP("InstrumentsXML", "She."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Sheng"),
//: Soprano Sheng
QT_TRANSLATE_NOOP("InstrumentsXML", "S She."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Sheng"),
//: Alto Sheng
QT_TRANSLATE_NOOP("InstrumentsXML", "A She."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Sheng"),
//: Tenor Sheng
QT_TRANSLATE_NOOP("InstrumentsXML", "T She."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Sheng"),
//: Bass Sheng
QT_TRANSLATE_NOOP("InstrumentsXML", "B She."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Brass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Brass"),
//: Brass
QT_TRANSLATE_NOOP("InstrumentsXML", "Br."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in F"),
//: Horn in F
QT_TRANSLATE_NOOP("InstrumentsXML", "F Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "High C Horn"),
//: High C Horn
QT_TRANSLATE_NOOP("InstrumentsXML", "H. C Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in B♭"),
//: Horn in B♭
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in A"),
//: Horn in A
QT_TRANSLATE_NOOP("InstrumentsXML", "A Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in A♭"),
//: Horn in A♭
QT_TRANSLATE_NOOP("InstrumentsXML", "A♭ Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in G"),
//: Horn in G
QT_TRANSLATE_NOOP("InstrumentsXML", "G Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E Horn"),
//: E Horn
QT_TRANSLATE_NOOP("InstrumentsXML", "E Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in E♭"),
//: Horn in E♭
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in D"),
//: Horn in D
QT_TRANSLATE_NOOP("InstrumentsXML", "Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in C"),
//: Horn in C
QT_TRANSLATE_NOOP("InstrumentsXML", "C Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vienna Horn"),
//: Vienna Horn
QT_TRANSLATE_NOOP("InstrumentsXML", "V. Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in B♭ basso"),
//: Horn in B♭ basso
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ ba Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Cornet"),
//: E♭ Cornet
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Cnt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Cornet"),
//: C Cornet
QT_TRANSLATE_NOOP("InstrumentsXML", "C Cnt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Cornet"),
//: B♭ Cornet
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Cnt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Cornet"),
//: A Cornet
QT_TRANSLATE_NOOP("InstrumentsXML", "A Cnt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Saxhorn"),
//: Saxhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "Saxhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Alto Horn"),
//: F Alto Horn
QT_TRANSLATE_NOOP("InstrumentsXML", "F A. Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Alto Horn"),
//: E♭ Alto Horn
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ A. Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Horn"),
//: Baritone Horn
QT_TRANSLATE_NOOP("InstrumentsXML", "Bar. Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Horn"),
//: Baritone Horn
QT_TRANSLATE_NOOP("InstrumentsXML", "Bar. Hn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Horn (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Posthorn"),
//: Posthorn
QT_TRANSLATE_NOOP("InstrumentsXML", "Psthn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alphorn"),
//: Alphorn
QT_TRANSLATE_NOOP("InstrumentsXML", "AlpHn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Trumpet"),
//: Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Trumpet"),
//: Piccolo Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "P. Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Trumpet in B♭"),
//: Piccolo Trumpet in B♭
QT_TRANSLATE_NOOP("InstrumentsXML", "P. Tpt. B♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Trumpet in A"),
//: Piccolo Trumpet in A
QT_TRANSLATE_NOOP("InstrumentsXML", "P. Tpt. A"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Trumpet"),
//: F Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "F Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E Trumpet"),
//: E Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "E Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Trumpet"),
//: E♭ Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "D Trumpet"),
//: D Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "D Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Trumpet"),
//: C Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "C Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Trumpet"),
//: B♭ Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Trumpet"),
//: A Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "A Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pocket Trumpet"),
//: Pocket Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "Pkt. Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Slide Trumpet"),
//: Slide Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "Sl.Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Trumpet"),
//: Tenor Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "Tnr. Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Trumpet"),
//: Bass Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Bass Trumpet"),
//: E♭ Bass Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ B. Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Trumpet in C"),
//: Bass Trumpet in C
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Tpt. C"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Bass Trumpet"),
//: B♭ Bass Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ B. Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet"),
//: Baroque Trumpet
QT_TRANSLATE_NOOP("InstrumentsXML", "Bq. Tpt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in F"),
//: Baroque Trumpet in F
QT_TRANSLATE_NOOP("InstrumentsXML", "Bq. Tpt. F"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in E♭"),
//: Baroque Trumpet in E♭
QT_TRANSLATE_NOOP("InstrumentsXML", "Bq. Tpt. E♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in D"),
//: Baroque Trumpet in D
QT_TRANSLATE_NOOP("InstrumentsXML", "Bq. Tpt. D"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in C"),
//: Baroque Trumpet in C
QT_TRANSLATE_NOOP("InstrumentsXML", "Bq. Tpt. C"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in B♭"),
//: Baroque Trumpet in B♭
QT_TRANSLATE_NOOP("InstrumentsXML", "Bq. Tpt. B♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rag Dung"),
//: Rag Dung
QT_TRANSLATE_NOOP("InstrumentsXML", "Rg. Dng."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bugle"),
//: Bugle
QT_TRANSLATE_NOOP("InstrumentsXML", "Bu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Bugle"),
//: Soprano Bugle
QT_TRANSLATE_NOOP("InstrumentsXML", "Sop. Bu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Bugle"),
//: Alto Bugle
QT_TRANSLATE_NOOP("InstrumentsXML", "Alt. Bu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Bugle"),
//: Baritone Bugle
QT_TRANSLATE_NOOP("InstrumentsXML", "Bar. Bu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Flugelhorn"),
//: Flugelhorn
QT_TRANSLATE_NOOP("InstrumentsXML", "Flghn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Fiscorn"),
//: Fiscorn
QT_TRANSLATE_NOOP("InstrumentsXML", "Fsc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Kuhlohorn"),
//: Kuhlohorn
QT_TRANSLATE_NOOP("InstrumentsXML", "Klhn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Euphonium Bugle"),
//: Euphonium Bugle
QT_TRANSLATE_NOOP("InstrumentsXML", "Euph. Bu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mellophone Bugle"),
//: Mellophone Bugle
QT_TRANSLATE_NOOP("InstrumentsXML", "Mel. Bu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Bugle"),
//: Contrabass Bugle
QT_TRANSLATE_NOOP("InstrumentsXML", "Con. Bu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mellophone"),
//: Mellophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Mph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ophicleide"),
//: Ophicleide
QT_TRANSLATE_NOOP("InstrumentsXML", "Oph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Alto Ophicleide"),
//: F Alto Ophicleide
QT_TRANSLATE_NOOP("InstrumentsXML", "F A. Oph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Alto Ophicleide"),
//: E♭ Alto Ophicleide
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ A. Oph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Bass Ophicleide"),
//: C Bass Ophicleide
QT_TRANSLATE_NOOP("InstrumentsXML", "C B. Oph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Bass Ophicleide"),
//: B♭ Bass Ophicleide
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ B. Oph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Contrabass Ophicleide"),
//: E♭ Contrabass Ophicleide
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Cb. Oph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cornettino"),
//: Cornettino
QT_TRANSLATE_NOOP("InstrumentsXML", "Co."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cornett"),
//: Cornett
QT_TRANSLATE_NOOP("InstrumentsXML", "Co."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Cornett"),
//: Soprano Cornett
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Co."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Cornett"),
//: Alto Cornett
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Co."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Cornett"),
//: Tenor Cornett
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Co."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Serpent"),
//: Serpent
QT_TRANSLATE_NOOP("InstrumentsXML", "Spt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Trombone"),
//: Trombone
QT_TRANSLATE_NOOP("InstrumentsXML", "Tbn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Trombone"),
//: Trombone
QT_TRANSLATE_NOOP("InstrumentsXML", "Tbn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Trombone (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Trombone"),
//: Soprano Trombone
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Tbn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Trombone"),
//: Alto Trombone
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Tbn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Trombone"),
//: Tenor Trombone
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Tbn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Trombone"),
//: Bass Trombone
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Tbn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Trombone"),
//: Contrabass Trombone
QT_TRANSLATE_NOOP("InstrumentsXML", "Cb. Tbn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cimbasso"),
//: Cimbasso
QT_TRANSLATE_NOOP("InstrumentsXML", "Cim."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Euphonium"),
//: Euphonium
QT_TRANSLATE_NOOP("InstrumentsXML", "Euph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Euphonium"),
//: Euphonium
QT_TRANSLATE_NOOP("InstrumentsXML", "Euph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Euphonium (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tuba"),
//: Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "Tba."),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Tuba"),
//: F Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "F Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tuba"),
//: E♭ Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tuba"),
//: E♭ Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tuba (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Tuba"),
//: C Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "C Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tuba"),
//: B♭ Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tuba"),
//: B♭ Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tuba (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Tuba in F"),
//: Bass Tuba in F
QT_TRANSLATE_NOOP("InstrumentsXML", "Ba. Tu. F"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Tuba in E♭"),
//: Bass Tuba in E♭
QT_TRANSLATE_NOOP("InstrumentsXML", "Ba. Tu. E♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sub-Contrabass Tuba"),
//: Sub-Contrabass Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "SCB. Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Helicon"),
//: Helicon
QT_TRANSLATE_NOOP("InstrumentsXML", "Helicon"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sousaphone"),
//: Sousaphone
QT_TRANSLATE_NOOP("InstrumentsXML", "Sphn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Wagner Tuba"),
//: Wagner Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "Wag. Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Wagner Tuba"),
//: B♭ Wagner Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Wag. Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Wagner Tuba"),
//: F Wagner Tuba
QT_TRANSLATE_NOOP("InstrumentsXML", "F Wag. Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Conch"),
//: Conch
QT_TRANSLATE_NOOP("InstrumentsXML", "Cnch."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Didgeridoo"),
//: Didgeridoo
QT_TRANSLATE_NOOP("InstrumentsXML", "Doo."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horagai"),
//: Horagai
QT_TRANSLATE_NOOP("InstrumentsXML", "Hor."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Shofar"),
//: Shofar
QT_TRANSLATE_NOOP("InstrumentsXML", "Sho."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vuvuzela"),
//: Vuvuzela
QT_TRANSLATE_NOOP("InstrumentsXML", "Vuv."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pitched Percussion"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Timpani"),
//: Timpani
QT_TRANSLATE_NOOP("InstrumentsXML", "Timp."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Roto-toms"),
//: Roto-toms
QT_TRANSLATE_NOOP("InstrumentsXML", "Rt-t."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Glockenspiel"),
//: Glockenspiel
QT_TRANSLATE_NOOP("InstrumentsXML", "Glk."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Soprano Glockenspiel"),
//: Orff Soprano Glockenspiel
QT_TRANSLATE_NOOP("InstrumentsXML", "O. S. Glk."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Alto Glockenspiel"),
//: Orff Alto Glockenspiel
QT_TRANSLATE_NOOP("InstrumentsXML", "O. A. Glk."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Crotales"),
//: Crotales
QT_TRANSLATE_NOOP("InstrumentsXML", "Cro."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tubaphone"),
//: Tubaphone
QT_TRANSLATE_NOOP("InstrumentsXML", "Tph."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Almglocken"),
//: Almglocken
QT_TRANSLATE_NOOP("InstrumentsXML", "Agl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vibraphone"),
//: Vibraphone
QT_TRANSLATE_NOOP("InstrumentsXML", "Vib."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Metallophone"),
//: Metallophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Met."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Soprano Metallophone"),
//: Orff Soprano Metallophone
QT_TRANSLATE_NOOP("InstrumentsXML", "O. S. Met."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Alto Metallophone"),
//: Orff Alto Metallophone
QT_TRANSLATE_NOOP("InstrumentsXML", "O. A. Met."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Bass Metallophone"),
//: Orff Bass Metallophone
QT_TRANSLATE_NOOP("InstrumentsXML", "O. B. Met."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tubular Bells"),
//: Tubular Bells
QT_TRANSLATE_NOOP("InstrumentsXML", "Tu. Be."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Steel Drums"),
//: Steel Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "St. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Steel Drums"),
//: Soprano Steel Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "S. St. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Steel Drums"),
//: Alto Steel Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "A. St. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar Steel Drums"),
//: Guitar Steel Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "Gtr. St. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Steel Drums"),
//: Tenor Steel Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "T. St. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cello Steel Drums"),
//: Cello Steel Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "Ce. St. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Steel Drums"),
//: Bass Steel Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "B. St. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hand Bells"),
//: Hand Bells
QT_TRANSLATE_NOOP("InstrumentsXML", "Ha. Be."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tuned Gongs"),
//: Tuned Gongs
QT_TRANSLATE_NOOP("InstrumentsXML", "Td. Go."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Flexatone"),
//: Flexatone
QT_TRANSLATE_NOOP("InstrumentsXML", "Flt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Musical Saw"),
//: Musical Saw
QT_TRANSLATE_NOOP("InstrumentsXML", "Mu. Sw."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Musical Glasses"),
//: Musical Glasses
QT_TRANSLATE_NOOP("InstrumentsXML", "Mu. Gla."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Glass Harmonica"),
//: Glass Harmonica
QT_TRANSLATE_NOOP("InstrumentsXML", "Gla. Har."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Xylophone"),
//: Xylophone
QT_TRANSLATE_NOOP("InstrumentsXML", "Xyl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Soprano Xylophone"),
//: Orff Soprano Xylophone
QT_TRANSLATE_NOOP("InstrumentsXML", "O. S. Xyl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Alto Xylophone"),
//: Orff Alto Xylophone
QT_TRANSLATE_NOOP("InstrumentsXML", "O. A. Xyl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Bass Xylophone"),
//: Orff Bass Xylophone
QT_TRANSLATE_NOOP("InstrumentsXML", "O. B. Xyl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Xylomarimba"),
//: Xylomarimba
QT_TRANSLATE_NOOP("InstrumentsXML", "XMrm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Marimba"),
//: Marimba
QT_TRANSLATE_NOOP("InstrumentsXML", "Mrm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Marimba"),
//: Bass Marimba
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Mrm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Dulcimer"),
//: Dulcimer
QT_TRANSLATE_NOOP("InstrumentsXML", "Dlc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tuned Klaxon Horns"),
//: Tuned Klaxon Horns
QT_TRANSLATE_NOOP("InstrumentsXML", "Tn. Klx. Hns."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Kalimba"),
//: Kalimba
QT_TRANSLATE_NOOP("InstrumentsXML", "Kal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Treble Kalimba"),
//: Treble Kalimba
QT_TRANSLATE_NOOP("InstrumentsXML", "Tr. Kal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Kalimba"),
//: Alto Kalimba
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Kal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Unpitched Percussion"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Drumset"),
//: Drumset
QT_TRANSLATE_NOOP("InstrumentsXML", "Drs."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Snare Drum"),
//: Snare Drum
QT_TRANSLATE_NOOP("InstrumentsXML", "Sn. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Drum"),
//: Bass Drum
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Snare Drum"),
//: Piccolo Snare Drum
QT_TRANSLATE_NOOP("InstrumentsXML", "P. Sn. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Military Drum"),
//: Military Drum
QT_TRANSLATE_NOOP("InstrumentsXML", "Mil. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tom Toms"),
//: Tom Toms
QT_TRANSLATE_NOOP("InstrumentsXML", "Toms"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Chinese Tom-toms"),
//: Chinese Tom-toms
QT_TRANSLATE_NOOP("InstrumentsXML", "Ch. To."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bongos"),
//: Bongos
QT_TRANSLATE_NOOP("InstrumentsXML", "Bo."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Congas"),
//: Congas
QT_TRANSLATE_NOOP("InstrumentsXML", "Co."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Timbales"),
//: Timbales
QT_TRANSLATE_NOOP("InstrumentsXML", "Timb."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Frame Drum"),
//: Frame Drum
QT_TRANSLATE_NOOP("InstrumentsXML", "Fr. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tablas"),
//: Tablas
QT_TRANSLATE_NOOP("InstrumentsXML", "Tbs."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cuica"),
//: Cuica
QT_TRANSLATE_NOOP("InstrumentsXML", "Cu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Finger Cymbals"),
//: Finger Cymbals
QT_TRANSLATE_NOOP("InstrumentsXML", "Fi. Cym."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hi-hat"),
//: Hi-hat
QT_TRANSLATE_NOOP("InstrumentsXML", "Hi-hat"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tam-tam"),
//: Tam-tam
QT_TRANSLATE_NOOP("InstrumentsXML", "Tam-tam"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bells"),
//: Bells
QT_TRANSLATE_NOOP("InstrumentsXML", "Be."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sleigh Bells"),
//: Sleigh Bells
QT_TRANSLATE_NOOP("InstrumentsXML", "Sle. Be."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bell Plate"),
//: Bell Plate
QT_TRANSLATE_NOOP("InstrumentsXML", "Be. Pla."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bowl Gongs"),
//: Bowl Gongs
QT_TRANSLATE_NOOP("InstrumentsXML", "Bw. Go."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tubo"),
//: Tubo
QT_TRANSLATE_NOOP("InstrumentsXML", "Tu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Metal Castanets"),
//: Metal Castanets
QT_TRANSLATE_NOOP("InstrumentsXML", "Met. Cst."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Automobile Brake Drums"),
//: Automobile Brake Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "Aut. Brk. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Iron Pipes"),
//: Iron Pipes
QT_TRANSLATE_NOOP("InstrumentsXML", "Ir. Pi."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Chains"),
//: Chains
QT_TRANSLATE_NOOP("InstrumentsXML", "Chn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Anvil"),
//: Anvil
QT_TRANSLATE_NOOP("InstrumentsXML", "Anv."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Wood Blocks"),
//: Wood Blocks
QT_TRANSLATE_NOOP("InstrumentsXML", "Wd. Bl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Temple Blocks"),
//: Temple Blocks
QT_TRANSLATE_NOOP("InstrumentsXML", "Tmp. Bl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Triangle"),
//: Triangle
QT_TRANSLATE_NOOP("InstrumentsXML", "Trgl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cymbal"),
//: Cymbal
QT_TRANSLATE_NOOP("InstrumentsXML", "Cym."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ride Cymbal"),
//: Ride Cymbal
QT_TRANSLATE_NOOP("InstrumentsXML", "R. Cym."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Chinese Cymbal"),
//: Chinese Cymbal
QT_TRANSLATE_NOOP("InstrumentsXML", "Ch. Cym."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Crash Cymbal"),
//: Crash Cymbal
QT_TRANSLATE_NOOP("InstrumentsXML", "Cr. Cym."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Splash Cymbal"),
//: Splash Cymbal
QT_TRANSLATE_NOOP("InstrumentsXML", "Sp. Cym."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cowbell"),
//: Cowbell
QT_TRANSLATE_NOOP("InstrumentsXML", "Cwb."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Claves"),
//: Claves
QT_TRANSLATE_NOOP("InstrumentsXML", "Clv."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Castanets"),
//: Castanets
QT_TRANSLATE_NOOP("InstrumentsXML", "Cst."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Guiro"),
//: Guiro
QT_TRANSLATE_NOOP("InstrumentsXML", "Gro."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Maracas"),
//: Maracas
QT_TRANSLATE_NOOP("InstrumentsXML", "Mrcs."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cabasa"),
//: Cabasa
QT_TRANSLATE_NOOP("InstrumentsXML", "Cab."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Quijada"),
//: Quijada
QT_TRANSLATE_NOOP("InstrumentsXML", "Qui."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vibraslap"),
//: Vibraslap
QT_TRANSLATE_NOOP("InstrumentsXML", "Vibslp."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Slit Drum"),
//: Slit Drum
QT_TRANSLATE_NOOP("InstrumentsXML", "Slt. Dr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Whip"),
//: Whip
QT_TRANSLATE_NOOP("InstrumentsXML", "Wh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ratchet"),
//: Ratchet
QT_TRANSLATE_NOOP("InstrumentsXML", "Rat."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Thundersheet"),
//: Thundersheet
QT_TRANSLATE_NOOP("InstrumentsXML", "Thu."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sandpaper Blocks"),
//: Sandpaper Blocks
QT_TRANSLATE_NOOP("InstrumentsXML", "Sa. Bl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Wooden Wind Chimes"),
//: Wooden Wind Chimes
QT_TRANSLATE_NOOP("InstrumentsXML", "Wd. Wn. Ch."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bamboo Wind Chimes"),
//: Bamboo Wind Chimes
QT_TRANSLATE_NOOP("InstrumentsXML", "Bam. Wn. Ch."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Metal Wind Chimes"),
//: Metal Wind Chimes
QT_TRANSLATE_NOOP("InstrumentsXML", "Met. Wn Ch."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Glass Wind Chimes"),
//: Glass Wind Chimes
QT_TRANSLATE_NOOP("InstrumentsXML", "Gl. Wn Ch."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Shell Wind Chimes"),
//: Shell Wind Chimes
QT_TRANSLATE_NOOP("InstrumentsXML", "Sh. Wn Ch."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Stones"),
//: Stones
QT_TRANSLATE_NOOP("InstrumentsXML", "Sto."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Finger Snap"),
//: Finger Snap
QT_TRANSLATE_NOOP("InstrumentsXML", "Fi. Sna."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hand Clap"),
//: Hand Clap
QT_TRANSLATE_NOOP("InstrumentsXML", "Hd. Clp."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Slap"),
//: Slap
QT_TRANSLATE_NOOP("InstrumentsXML", "Sla."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Stamp"),
//: Stamp
QT_TRANSLATE_NOOP("InstrumentsXML", "Sta."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tambourine"),
//: Tambourine
QT_TRANSLATE_NOOP("InstrumentsXML", "Tamb."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Marching Percussion"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Snare Drum"),
//: Snare Drum
QT_TRANSLATE_NOOP("InstrumentsXML", "SD"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Drums"),
//: Tenor Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "TD"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Drums"),
//: Bass Drums
QT_TRANSLATE_NOOP("InstrumentsXML", "BD"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cymbals"),
//: Cymbals
QT_TRANSLATE_NOOP("InstrumentsXML", "Cy"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vocals"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Voice"),
//: Voice
QT_TRANSLATE_NOOP("InstrumentsXML", "Vo."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Boy Soprano"),
//: Boy Soprano
QT_TRANSLATE_NOOP("InstrumentsXML", "B. S."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano"),
//: Soprano
QT_TRANSLATE_NOOP("InstrumentsXML", "S."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mezzo-soprano"),
//: Mezzo-soprano
QT_TRANSLATE_NOOP("InstrumentsXML", "Mzs."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto"),
//: Alto
QT_TRANSLATE_NOOP("InstrumentsXML", "A."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contralto"),
//: Contralto
QT_TRANSLATE_NOOP("InstrumentsXML", "Contr."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Countertenor"),
//: Countertenor
QT_TRANSLATE_NOOP("InstrumentsXML", "Ct."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor"),
//: Tenor
QT_TRANSLATE_NOOP("InstrumentsXML", "T."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone"),
//: Baritone
QT_TRANSLATE_NOOP("InstrumentsXML", "Bar."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass"),
//: Bass
QT_TRANSLATE_NOOP("InstrumentsXML", "B."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Kazoo"),
//: Kazoo
QT_TRANSLATE_NOOP("InstrumentsXML", "Kaz."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Keyboards"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piano"),
//: Piano
QT_TRANSLATE_NOOP("InstrumentsXML", "Pno."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Grand Piano"),
//: Grand Piano
QT_TRANSLATE_NOOP("InstrumentsXML", "Pno."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Upright Piano"),
//: Upright Piano
QT_TRANSLATE_NOOP("InstrumentsXML", "Pno."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Honky Tonk Piano"),
//: Honky Tonk Piano
QT_TRANSLATE_NOOP("InstrumentsXML", "Hnk. Pno."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Toy Piano"),
//: Toy Piano
QT_TRANSLATE_NOOP("InstrumentsXML", "Toy Pno."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Clavichord"),
//: Clavichord
QT_TRANSLATE_NOOP("InstrumentsXML", "Cch."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Harpsichord"),
//: Harpsichord
QT_TRANSLATE_NOOP("InstrumentsXML", "Hch."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Virginal"),
//: Virginal
QT_TRANSLATE_NOOP("InstrumentsXML", "Vir."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Celesta"),
//: Celesta
QT_TRANSLATE_NOOP("InstrumentsXML", "Cel."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Piano"),
//: Electric Piano
QT_TRANSLATE_NOOP("InstrumentsXML", "El. Pno."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Clavinet"),
//: Clavinet
QT_TRANSLATE_NOOP("InstrumentsXML", "Clav."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Organ"),
//: Organ
QT_TRANSLATE_NOOP("InstrumentsXML", "Org."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Percussive Organ"),
//: Percussive Organ
QT_TRANSLATE_NOOP("InstrumentsXML", "Perc. Org."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hammond Organ"),
//: Hammond Organ
QT_TRANSLATE_NOOP("InstrumentsXML", "Hm. Org."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rotary Organ"),
//: Rotary Organ
QT_TRANSLATE_NOOP("InstrumentsXML", "Rot. Org."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pipe Organ"),
//: Pipe Organ
QT_TRANSLATE_NOOP("InstrumentsXML", "Org."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pipe Organ"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Harmonium"),
//: Harmonium
QT_TRANSLATE_NOOP("InstrumentsXML", "Harm."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Reed Organ"),
//: Reed Organ
QT_TRANSLATE_NOOP("InstrumentsXML", "Rd. Org."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electronic Instruments"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Effect Synthesizer"),
//: Effect Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "rain"),
QT_TRANSLATE_NOOP("InstrumentsXML", "soundtrack"),
QT_TRANSLATE_NOOP("InstrumentsXML", "crystal"),
QT_TRANSLATE_NOOP("InstrumentsXML", "atmosphere"),
QT_TRANSLATE_NOOP("InstrumentsXML", "brightness"),
QT_TRANSLATE_NOOP("InstrumentsXML", "goblins"),
QT_TRANSLATE_NOOP("InstrumentsXML", "echoes"),
QT_TRANSLATE_NOOP("InstrumentsXML", "scifi"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Atmosphere Synthesizer"),
//: Atmosphere Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Brightness Synthesizer"),
//: Brightness Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Crystal Synthesizer"),
//: Crystal Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Echoes Synthesizer"),
//: Echoes Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Goblins Synthesizer"),
//: Goblins Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rain Synthesizer"),
//: Rain Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sci-fi Synthesizer"),
//: Sci-fi Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soundtrack Synthesizer"),
//: Soundtrack Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pad Synthesizer"),
//: Pad Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "new age"),
QT_TRANSLATE_NOOP("InstrumentsXML", "warm"),
QT_TRANSLATE_NOOP("InstrumentsXML", "polysynth"),
QT_TRANSLATE_NOOP("InstrumentsXML", "choir"),
QT_TRANSLATE_NOOP("InstrumentsXML", "bowed"),
QT_TRANSLATE_NOOP("InstrumentsXML", "metallic"),
QT_TRANSLATE_NOOP("InstrumentsXML", "halo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "sweep"),
QT_TRANSLATE_NOOP("InstrumentsXML", "New Age Synthesizer"),
//: New Age Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Warm Synthesizer"),
//: Warm Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Poly Synthesizer"),
//: Poly Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Choir Synthesizer"),
//: Choir Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bowed Synthesizer"),
//: Bowed Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Metallic Synthesizer"),
//: Metallic Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Halo Synthesizer"),
//: Halo Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sweep Synthesizer"),
//: Sweep Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Saw Synthesizer"),
//: Saw Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sine Synthesizer"),
//: Sine Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Square Synthesizer"),
//: Square Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ondes Martenot"),
//: Ondes Martenot
QT_TRANSLATE_NOOP("InstrumentsXML", "O.M."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mallet Synthesizer"),
//: Mallet Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Mal. Syn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Synthesizer"),
//: Bass Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-bass-1"),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-bass-2"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Brass Synthesizer"),
//: Brass Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-brass-1"),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-brass-2"),
QT_TRANSLATE_NOOP("InstrumentsXML", "String Synthesizer"),
//: String Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Synth."),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-string-1"),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-string-2"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Theremin"),
//: Theremin
QT_TRANSLATE_NOOP("InstrumentsXML", "Thmn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion Synthesizer"),
//: Percussion Synthesizer
QT_TRANSLATE_NOOP("InstrumentsXML", "Perc. Syn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Plucked Strings"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Banjo"),
//: Banjo
QT_TRANSLATE_NOOP("InstrumentsXML", "Bj."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Banjo [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Banjo"),
//: Tenor Banjo
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Bj."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Balalaika"),
//: Balalaika
QT_TRANSLATE_NOOP("InstrumentsXML", "Bal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Balalaika"),
//: Piccolo Balalaika
QT_TRANSLATE_NOOP("InstrumentsXML", "Pic. Bal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Prima Balalaika"),
//: Prima Balalaika
QT_TRANSLATE_NOOP("InstrumentsXML", "Pr. Bal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Prima Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Secunda Balalaika"),
//: Secunda Balalaika
QT_TRANSLATE_NOOP("InstrumentsXML", "Sec. Bal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Secunda Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Balalaika"),
//: Alto Balalaika
QT_TRANSLATE_NOOP("InstrumentsXML", "Al. Bal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Balalaika"),
//: Bass Balalaika
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Bal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Balalaika"),
//: Contrabass Balalaika
QT_TRANSLATE_NOOP("InstrumentsXML", "CB. Bal."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bouzouki"),
//: Bouzouki
QT_TRANSLATE_NOOP("InstrumentsXML", "Bou."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bouzouki (3-course)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bouzouki"),
//: Bouzouki
QT_TRANSLATE_NOOP("InstrumentsXML", "Bou."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bouzouki (4-course)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Guitar"),
//: Soprano Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "S. Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Guitar"),
//: Alto Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Classical Guitar"),
//: Classical Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Classical Guitar [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contra Guitar"),
//: Contra Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "C Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Guitar"),
//: Acoustic Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Guitar [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "11-string Alto Guitar"),
//: 11-string Alto Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "11-str. A. Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "12-string Guitar"),
//: 12-string Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "12-str. Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pedal Steel Guitar"),
//: Pedal Steel Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "Ped. St. Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar"),
//: Electric Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "El. Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Harp"),
//: Harp
QT_TRANSLATE_NOOP("InstrumentsXML", "Hrp."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Koto"),
//: Koto
QT_TRANSLATE_NOOP("InstrumentsXML", "Ko."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
//: Lute
QT_TRANSLATE_NOOP("InstrumentsXML", "Lt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
//: Lute
QT_TRANSLATE_NOOP("InstrumentsXML", "Lt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 5-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
//: Lute
QT_TRANSLATE_NOOP("InstrumentsXML", "Lt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 6-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
//: Lute
QT_TRANSLATE_NOOP("InstrumentsXML", "Lt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 7-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
//: Lute
QT_TRANSLATE_NOOP("InstrumentsXML", "Lt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 8-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
//: Lute
QT_TRANSLATE_NOOP("InstrumentsXML", "Lt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 9-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
//: Lute
QT_TRANSLATE_NOOP("InstrumentsXML", "Lt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 10-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
//: Lute
QT_TRANSLATE_NOOP("InstrumentsXML", "Lt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 13-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Archlute"),
//: Archlute
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Lt."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Theorbo"),
//: Theorbo
QT_TRANSLATE_NOOP("InstrumentsXML", "Thb."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mandolin"),
//: Mandolin
QT_TRANSLATE_NOOP("InstrumentsXML", "Mdn."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mandolin [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mandola"),
//: Mandola
QT_TRANSLATE_NOOP("InstrumentsXML", "Mda."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Mandola"),
//: Alto Mandola
QT_TRANSLATE_NOOP("InstrumentsXML", "Mda."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Mandola"),
//: Tenor Mandola
QT_TRANSLATE_NOOP("InstrumentsXML", "Mda."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mandocello"),
//: Mandocello
QT_TRANSLATE_NOOP("InstrumentsXML", "Mncl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Octave Mandolin"),
//: Octave Mandolin
QT_TRANSLATE_NOOP("InstrumentsXML", "OM."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Shamisen"),
//: Shamisen
QT_TRANSLATE_NOOP("InstrumentsXML", "Sh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sitar"),
//: Sitar
QT_TRANSLATE_NOOP("InstrumentsXML", "Si."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ukulele"),
//: Ukulele
QT_TRANSLATE_NOOP("InstrumentsXML", "Uk."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ukulele [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Ukulele"),
//: Tenor Ukulele
QT_TRANSLATE_NOOP("InstrumentsXML", "Ten. Uk."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Ukulele"),
//: Baritone Ukulele
QT_TRANSLATE_NOOP("InstrumentsXML", "Bar. Uk."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Guitar"),
//: Bass Guitar
QT_TRANSLATE_NOOP("InstrumentsXML", "B. Guit."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Guitar [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Bass"),
//: Acoustic Bass
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "arco"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Bass"),
//: Electric Bass
QT_TRANSLATE_NOOP("InstrumentsXML", "El. B."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Bass [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Fretless Electric Bass"),
//: Fretless Electric Bass
QT_TRANSLATE_NOOP("InstrumentsXML", "Frtl. El. B."),
QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass"),
//: 5-str. Electric Bass
QT_TRANSLATE_NOOP("InstrumentsXML", "El. B."),
QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Strings"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Erhu"),
//: Erhu
QT_TRANSLATE_NOOP("InstrumentsXML", "Eh."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violin"),
//: Violin
QT_TRANSLATE_NOOP("InstrumentsXML", "Vln."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violins"),
//: Violins
QT_TRANSLATE_NOOP("InstrumentsXML", "Vlns."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Viola"),
//: Viola
QT_TRANSLATE_NOOP("InstrumentsXML", "Vla."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violas"),
//: Violas
QT_TRANSLATE_NOOP("InstrumentsXML", "Vlas."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violoncello"),
//: Violoncello
QT_TRANSLATE_NOOP("InstrumentsXML", "Vc."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violoncellos"),
//: Violoncellos
QT_TRANSLATE_NOOP("InstrumentsXML", "Vcs."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass"),
//: Contrabass
QT_TRANSLATE_NOOP("InstrumentsXML", "Cb."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabasses"),
//: Contrabasses
QT_TRANSLATE_NOOP("InstrumentsXML", "Cbs."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Double Bass"),
//: Double Bass
QT_TRANSLATE_NOOP("InstrumentsXML", "Db."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pardessus de viole"),
//: Pardessus de viole
QT_TRANSLATE_NOOP("InstrumentsXML", "Pds. v."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Treble Viol"),
//: Treble Viol
QT_TRANSLATE_NOOP("InstrumentsXML", "Tr. vl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Viol"),
//: Alto Viol
QT_TRANSLATE_NOOP("InstrumentsXML", "A. Vl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Viol"),
//: Tenor Viol
QT_TRANSLATE_NOOP("InstrumentsXML", "T. Vl."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba"),
//: Viola da gamba
QT_TRANSLATE_NOOP("InstrumentsXML", "Vla. d. g."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba (Tab)"),
//: Viola da gamba (Tab)
QT_TRANSLATE_NOOP("InstrumentsXML", "Vla. d. g."),
QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba (Tablature)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violone"),
//: Violone
QT_TRANSLATE_NOOP("InstrumentsXML", "Vne."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "D Violone"),
//: D Violone
QT_TRANSLATE_NOOP("InstrumentsXML", "Vne."),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
